import 'dart:math';

import 'package:animation_player/animation_player.dart';
import 'package:flutter/material.dart';

void main() => runApp(const App());

class App extends StatelessWidget {
  const App({Key key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: const _Home(),
    );
  }
}

class _Home extends StatelessWidget {
  const _Home({Key key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('AnimationPlayer example'),
      ),
      body: SafeArea(
        child: AnimationPlayer(
          duration: Duration(milliseconds: 400),
          autoReset: false,
          builder: (context, animation) => AnimatedBuilder(
            animation: animation,
            builder: (context, child) => AspectRatio(
              aspectRatio: 1,
              child: CustomPaint(
                painter: Check(progress: animation.value),
                child: child,
              ),
            ),
            child: SizedBox.expand(),
          ),
        ),
      ),
    );
  }
}

class Check extends CustomPainter {
  Check({
    @required this.progress,
  }) : super();
  final double progress;

  final _paint = Paint()
    ..strokeCap = StrokeCap.round
    ..style = PaintingStyle.stroke
    ..strokeWidth = 16;

  static const _defaultColor = Color(0xFF747474);
  static const _completedColor = Color(0xFF4D85F3);
  final _colorTween = ColorTween(
    begin: _defaultColor,
    end: _completedColor,
  );

  @override
  void paint(Canvas canvas, Size size) {
    print(size.width);
    final radius = size.width / 2;
    final center = Offset(radius, radius);
    _paint.color = _colorTween.lerp(progress);

//    final path = Path()
//      ..addArc(
//        Rect.fromCenter(
//          center: center,
//          width: size.width,
//          height: size.height,
//        ),
//        0,
//        5,
//      );
//    canvas.drawPath(path, _paint);
    canvas.drawArc(
      Rect.fromCircle(
        center: center,
        radius: radius,
      ),
      pi,
      2 * pi * max(0, 1 - progress * 2),
      false,
      _paint,
    );

    final path = Path()..moveTo(0, radius);
    final firstLineProgress = min(1, progress * 3);
    path.lineTo(
      radius * 0.6 * firstLineProgress,
      radius + radius * 0.5 * firstLineProgress,
    );
    if (firstLineProgress == 1) {
      final secondLineProgress = (progress - 1 / 3) * 1.5;
      path.lineTo(
        radius * 0.6 + radius * 1.2 * secondLineProgress,
        radius * 1.5 - radius * 1.3 * secondLineProgress,
      );
    }
    canvas.drawPath(path, _paint);
  }

  @override
  bool shouldRepaint(Check oldDelegate) => oldDelegate.progress != progress;
}
